@@ -10,6 +10,7 @@ STATUS = (
     (1, "Publish")
 )
 
+
 class Post(models.Model):
     title = models.CharField(max_length=200, unique=False)
     slug = models.SlugField(max_length=200, unique=True, allow_unicode=True)
@@ -30,3 +31,8 @@ class Post(models.Model):
 
     def __str__(self):
         return self.title
+
+    def get_absolute_url(self):
+        from django.urls import reverse
+
+        return reverse("zenblog:post_detail", kwargs={"slug": str(self.slug)})
